==> firefox-61.0b6.source.tar.xz: firefox-61.0/browser/extensions/activity-stream/prerendered/locales/ur/activity-stream-strings.js <==
// Note - this is a generated ur file.
window.gActivityStreamStrings = {
  "newtab_page_title": "نیا ٹیب",
  "header_top_sites": "بہترین سائٹیں",
  "header_highlights": "شہ سرخياں",
  "header_recommended_by": "{provider} کی جانب سے تجویز کردہ",
  "context_menu_button_sr": "Open context menu for {title}",
  "section_context_menu_button_sr": "Open the section context menu",
  "type_label_visited": "دورہ شدہ",
  "type_label_bookmarked": "نشان شدہ",
  "type_label_recommended": "رجحان سازی",
  "type_label_pocket": "Pocket میں محفوظ شدہ",
  "type_label_downloaded": "Downloaded",
  "menu_action_bookmark": "نشانی",
  "menu_action_remove_bookmark": "نشانى ہٹائيں",
  "menu_action_open_new_window": "نئے دریچے میں کھولیں",
  "menu_action_open_private_window": "نئی نجی دریچے میں کھولیں",
  "menu_action_dismiss": "برخاست کریں",
  "menu_action_delete": "تاریخ سے حذف کریں",
  "menu_action_pin": "پن",
  "menu_action_unpin": "ان پن",
  "confirm_history_delete_p1": "کیا آپ کو یقین ہے کہ آپ اس صفحہ کا ہر نمونہ اپنے سابقات سے حذف کرنا چاہتے ہیں؟",
  "confirm_history_delete_notice_p2": "یہ عمل کلعدم نہیں ہو سکتا۔",
  "menu_action_save_to_pocket": "Pocket میں محفوظ کریں",
  "menu_action_delete_pocket": "Pocket سے جزف کریں",
  "menu_action_archive_pocket": "Archive in Pocket",
  "menu_action_show_file_mac_os": "Show in Finder",
  "menu_action_show_file_windows": "Open Containing Folder",
  "menu_action_show_file_linux": "Open Containing Folder",
  "menu_action_show_file_default": "Show File",
  "menu_action_open_file": "Open File",
  "menu_action_copy_download_link": "Copy Download Link",
  "menu_action_go_to_download_page": "Go to Download Page",
  "menu_action_remove_download": "Remove from History",
  "search_button": "تلاش",
  "search_header": "{search_engine_name} پر تلاش کریں",
  "search_web_placeholder": "ويب پر تلاش کريں",
  "section_disclaimer_topstories": "The most interesting stories on the web, selected based on what you read. From Pocket, now part of Mozilla.",
  "section_disclaimer_topstories_linktext": "سیکھیں کہ یہ کیسے کام کرتا ہے۔",
  "section_disclaimer_topstories_buttontext": "ٹھیک ہے مجھے سمجھ آگئی ہے",
  "prefs_home_header": "Firefox ابتائی مواد",
  "prefs_home_description": "Choose what content you want on your Firefox Home screen.",
  "prefs_section_rows_option": "{num} row;{num} rows",
  "prefs_search_header": "Web Search",
  "prefs_topsites_description": "سائٹس جو آُپ سب سے زیادہ ملاحظہ کرتے ہیں",
  "prefs_topstories_description2": "Great content from around the web, personalized for you",
  "prefs_topstories_options_sponsored_label": "Sponsored Stories",
  "prefs_topstories_sponsored_learn_more": "مزید سیکھیں",
  "prefs_highlights_description": "A selection of sites that you’ve saved or visited",
  "prefs_highlights_options_visited_label": "Visited Pages",
  "prefs_highlights_options_download_label": "Most Recent Download",
  "prefs_highlights_options_pocket_label": "Pages Saved to Pocket",
  "prefs_snippets_description": "Mozilla اورFirefox کی جانب سے تازہ کاریاں",
  "settings_pane_button_label": "اپنے نئے ٹیب کہ صفحہ کی تخصیص کریں",
  "settings_pane_topsites_header": "بہترین سائٹیں",
  "settings_pane_highlights_header": "شہ سرخياں",
  "settings_pane_highlights_options_bookmarks": "نشانیاں",
  "settings_pane_snippets_header": "سنپیٹ",
  "edit_topsites_button_text": "تدوین",
  "edit_topsites_edit_button": "اس سائٹ کی تدوین کریں",
  "topsites_form_add_header": "نئی بہترین سائٹ",
  "topsites_form_edit_header": "بہترین سائٹٹ کیی تدوین کریں",
  "topsites_form_title_label": "عنوان",
  "topsites_form_title_placeholder": "ایک عنوان داخل کریں",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "Custom Image URL",
  "topsites_form_url_placeholder": "ٹائپ کریں یا ایک URL چسباں کریں",
  "topsites_form_use_image_link": "Use a custom image…",
  "topsites_form_preview_button": "پیش منظر",
  "topsites_form_add_button": "اظافہ کریں",
  "topsites_form_save_button": "محفوظ کریں",
  "topsites_form_cancel_button": "منسوخ کریں",
  "topsites_form_url_validation": "جائز URL درکار ہے",
  "topsites_form_image_validation": "نقش لوڈ ہونے میں ناکام رہا۔ براہ مہربانی ایک مختلف URL کو آزمائیں۔",
  "pocket_read_more": "مشہور مضامین:",
  "pocket_read_even_more": "مزید کہانیاں دیکھیں",
  "highlights_empty_state": "Start browsing, and we’ll show some of the great articles, videos, and other pages you’ve recently visited or bookmarked here.",
  "topstories_empty_state": "You’ve caught up. Check back later for more top stories from {provider}. Can’t wait? Select a popular topic to find more great stories from around the web.",
  "manual_migration_explanation2": "Try Firefox with the bookmarks, history and passwords from another browser.",
  "manual_migration_cancel_button": "نہیں شکریہ",
  "manual_migration_import_button": "ابھی درآمد کری",
  "error_fallback_default_info": "Oops, something went wrong loading this content.",
  "error_fallback_default_refresh_suggestion": "Refresh page to try again.",
  "section_menu_action_remove_section": "Remove Section",
  "section_menu_action_collapse_section": "Collapse Section",
  "section_menu_action_expand_section": "Expand Section",
  "section_menu_action_manage_section": "Manage Section",
  "section_menu_action_add_topsite": "Add Top Site",
  "section_menu_action_move_up": "اوپر کریں",
  "section_menu_action_move_down": "نیچے کریں",
  "section_menu_action_privacy_notice": "رازداری کا نوٹس",
  "prefs_restore_defaults_button": "طےشدہ بحال کریں",
  "prefs_topstories_description": "اعلی میعار کا مواد جو شاید آپ بصورت دیگر کھو دیں",
  "settings_pane_header": "نئے َٹیب کی ترجیحات",
  "settings_pane_body2": "انتخاب کریں آپ اس صفحہ پر کیا دیکھنا چاہیں گے۔",
  "settings_pane_search_header": "تلاش",
  "settings_pane_search_body": "اپنے نئے ٹیب سے وہب پر تلاش کریں۔",
  "settings_pane_topsites_body": "اپنی سب سے زیادہ دورہ کردہ ویب سائٹ تک رسائی حاصل کریں۔",
  "settings_pane_topsites_options_showmore": "دو قطاریں دکھائیں",
  "settings_pane_highlights_options_visited": "ملاحظہ کیے گئے سائٹس",
  "settings_pane_done_button": "ہوگیا"
};

==> firefox-62.0b14.source.tar.xz: firefox-62.0/browser/extensions/activity-stream/prerendered/locales/ur/activity-stream-strings.js <==
// Note - this is a generated ur file.
window.gActivityStreamStrings = {
  "newtab_page_title": "نیا ٹیب",
  "header_top_sites": "بہترین سائٹیں",
  "header_highlights": "شہ سرخياں",
  "header_recommended_by": "{provider} کی جانب سے تجویز کردہ",
  "context_menu_button_sr": "Open context menu for {title}",
  "section_context_menu_button_sr": "Open the section context menu",
  "type_label_visited": "دورہ شدہ",
  "type_label_bookmarked": "نشان شدہ",
  "type_label_recommended": "رجحان سازی",
  "type_label_pocket": "Pocket میں محفوظ شدہ",
  "type_label_downloaded": "Downloaded",
  "menu_action_bookmark": "نشانی",
  "menu_action_remove_bookmark": "نشانى ہٹائيں",
  "menu_action_open_new_window": "نئے دریچے میں کھولیں",
  "menu_action_open_private_window": "نئی نجی دریچے میں کھولیں",
  "menu_action_dismiss": "برخاست کریں",
  "menu_action_delete": "تاریخ سے حذف کریں",
  "menu_action_pin": "پن",
  "menu_action_unpin": "ان پن",
  "confirm_history_delete_p1": "کیا آپ کو یقین ہے کہ آپ اس صفحہ کا ہر نمونہ اپنے سابقات سے حذف کرنا چاہتے ہیں؟",
  "confirm_history_delete_notice_p2": "یہ عمل کلعدم نہیں ہو سکتا۔",
  "menu_action_save_to_pocket": "Pocket میں محفوظ کریں",
  "menu_action_delete_pocket": "Pocket سے جزف کریں",
  "menu_action_archive_pocket": "Archive in Pocket",
  "menu_action_show_file_mac_os": "Show in Finder",
  "menu_action_show_file_windows": "Open Containing Folder",
  "menu_action_show_file_linux": "Open Containing Folder",
  "menu_action_show_file_default": "Show File",
  "menu_action_open_file": "Open File",
  "menu_action_copy_download_link": "Copy Download Link",
  "menu_action_go_to_download_page": "Go to Download Page",
  "menu_action_remove_download": "Remove from History",
  "search_button": "تلاش",
  "search_header": "{search_engine_name} پر تلاش کریں",
  "search_web_placeholder": "ويب پر تلاش کريں",
  "section_disclaimer_topstories": "The most interesting stories on the web, selected based on what you read. From Pocket, now part of Mozilla.",
  "section_disclaimer_topstories_linktext": "سیکھیں کہ یہ کیسے کام کرتا ہے۔",
  "section_disclaimer_topstories_buttontext": "ٹھیک ہے مجھے سمجھ آگئی ہے",
  "prefs_home_header": "Firefox ابتائی مواد",
  "prefs_home_description": "Choose what content you want on your Firefox Home screen.",
  "prefs_section_rows_option": "{num} row;{num} rows",
  "prefs_search_header": "Web Search",
  "prefs_topsites_description": "سائٹس جو آُپ سب سے زیادہ ملاحظہ کرتے ہیں",
  "prefs_topstories_description2": "Great content from around the web, personalized for you",
  "prefs_topstories_options_sponsored_label": "Sponsored Stories",
  "prefs_topstories_sponsored_learn_more": "مزید سیکھیں",
  "prefs_highlights_description": "A selection of sites that you’ve saved or visited",
  "prefs_highlights_options_visited_label": "Visited Pages",
  "prefs_highlights_options_download_label": "Most Recent Download",
  "prefs_highlights_options_pocket_label": "Pages Saved to Pocket",
  "prefs_snippets_description": "Mozilla اورFirefox کی جانب سے تازہ کاریاں",
  "settings_pane_button_label": "اپنے نئے ٹیب کہ صفحہ کی تخصیص کریں",
  "settings_pane_topsites_header": "بہترین سائٹیں",
  "settings_pane_highlights_header": "شہ سرخياں",
  "settings_pane_highlights_options_bookmarks": "نشانیاں",
  "settings_pane_snippets_header": "سنپیٹ",
  "edit_topsites_button_text": "تدوین",
  "edit_topsites_edit_button": "اس سائٹ کی تدوین کریں",
  "topsites_form_add_header": "نئی بہترین سائٹ",
  "topsites_form_edit_header": "بہترین سائٹٹ کیی تدوین کریں",
  "topsites_form_title_label": "عنوان",
  "topsites_form_title_placeholder": "ایک عنوان داخل کریں",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "Custom Image URL",
  "topsites_form_url_placeholder": "ٹائپ کریں یا ایک URL چسباں کریں",
  "topsites_form_use_image_link": "Use a custom image…",
  "topsites_form_preview_button": "پیش منظر",
  "topsites_form_add_button": "اظافہ کریں",
  "topsites_form_save_button": "محفوظ کریں",
  "topsites_form_cancel_button": "منسوخ کریں",
  "topsites_form_url_validation": "جائز URL درکار ہے",
  "topsites_form_image_validation": "نقش لوڈ ہونے میں ناکام رہا۔ براہ مہربانی ایک مختلف URL کو آزمائیں۔",
  "pocket_read_more": "مشہور مضامین:",
  "pocket_read_even_more": "مزید کہانیاں دیکھیں",
  "highlights_empty_state": "Start browsing, and we’ll show some of the great articles, videos, and other pages you’ve recently visited or bookmarked here.",
  "topstories_empty_state": "You’ve caught up. Check back later for more top stories from {provider}. Can’t wait? Select a popular topic to find more great stories from around the web.",
  "manual_migration_explanation2": "Try Firefox with the bookmarks, history and passwords from another browser.",
  "manual_migration_cancel_button": "نہیں شکریہ",
  "manual_migration_import_button": "ابھی درآمد کری",
  "error_fallback_default_info": "Oops, something went wrong loading this content.",
  "error_fallback_default_refresh_suggestion": "Refresh page to try again.",
  "section_menu_action_remove_section": "Remove Section",
  "section_menu_action_collapse_section": "Collapse Section",
  "section_menu_action_expand_section": "Expand Section",
  "section_menu_action_manage_section": "Manage Section",
  "section_menu_action_manage_webext": "Manage Extension",
  "section_menu_action_add_topsite": "Add Top Site",
  "section_menu_action_move_up": "اوپر کریں",
  "section_menu_action_move_down": "نیچے کریں",
  "section_menu_action_privacy_notice": "رازداری کا نوٹس",
  "firstrun_title": "Take Firefox with You",
  "firstrun_content": "Get your bookmarks, history, passwords and other settings on all your devices.",
  "firstrun_learn_more_link": "Learn more about Firefox Accounts",
  "firstrun_form_header": "Enter your email",
  "firstrun_form_sub_header": "to continue to Firefox Sync",
  "firstrun_email_input_placeholder": "Email",
  "firstrun_extra_legal_links": "By proceeding, you agree to the {terms} and {privacy}.",
  "firstrun_terms_of_service": "Terms of Service",
  "firstrun_privacy_notice": "Privacy Notice",
  "firstrun_continue_to_login": "Continue",
  "firstrun_skip_login": "Skip this step",
  "prefs_restore_defaults_button": "طےشدہ بحال کریں",
  "prefs_topstories_description": "اعلی میعار کا مواد جو شاید آپ بصورت دیگر کھو دیں",
  "settings_pane_header": "نئے َٹیب کی ترجیحات",
  "settings_pane_body2": "انتخاب کریں آپ اس صفحہ پر کیا دیکھنا چاہیں گے۔",
  "settings_pane_search_header": "تلاش",
  "settings_pane_search_body": "اپنے نئے ٹیب سے وہب پر تلاش کریں۔",
  "settings_pane_topsites_body": "اپنی سب سے زیادہ دورہ کردہ ویب سائٹ تک رسائی حاصل کریں۔",
  "settings_pane_topsites_options_showmore": "دو قطاریں دکھائیں",
  "settings_pane_highlights_options_visited": "ملاحظہ کیے گئے سائٹس",
  "settings_pane_done_button": "ہوگیا"
};
